@@ -468,6 +468,7 @@ int Preferences::ExplorerShell()
         ".mka;MKAFile\r\n"
         ".mks;MKSFile\r\n"
         ".mkv;MKVFile\r\n"
+        ".mlp;MLPFile\r\n"
         ".mod;modFile\r\n"
         ".mov;MOVFile\r\n"
         ".mp+;mpcFile\r\n"
@@ -500,7 +501,8 @@ int Preferences::ExplorerShell()
         ".smv;SMVFile\r\n"
         ".stl;STLFile\r\n"
         ".swf;FlashFile\r\n"
-        ".tp;FlashVideoFile\r\n"
+        ".tak;TakVideoFile\r\n"
+        ".tp;TPFile\r\n"
         ".trp;TRPFile\r\n"
         ".ts;tsFile\r\n"
         ".tta;TTAFile\r\n"
@@ -1051,6 +1053,7 @@ int Preferences::ShellToolTip()
         ".m4b;mpeg4File\r\n"
         ".m4v;mpeg4File\r\n"
         ".mac;APEFile\r\n"
+        ".mlp;MLPFile\r\n"
         ".mka;MKAFile\r\n"
         ".mks;MKSFile\r\n"
         ".mkv;MKVFile\r\n"
@@ -1086,7 +1089,8 @@ int Preferences::ShellToolTip()
         ".smv;SMVFile\r\n"
         ".stl;STLFile\r\n"
         ".swf;FlashFile\r\n"
-        ".tp;FlashVideoFile\r\n"
+        ".tak;TAKFile\r\n"
+        ".tp;TPFile\r\n"
         ".trp;TRPFile\r\n"
         ".ts;tsFile\r\n"
         ".tta;TTAFile\r\n"
